%define anolis_release 1
Summary: Collection of performance monitoring tools for Linux
Name: sysstat
Version: 12.7.2
Release: %{anolis_release}%{?dist}
License: GPLv2+
URL: http://sebastien.godard.pagesperso-orange.fr/
Source: https://github.com/sysstat/sysstat/archive/v%{version}.tar.gz

# Use colors in sysstat output
Source1: colorsysstat.csh
Source2: colorsysstat.sh

BuildRequires: make
BuildRequires: gcc, gettext, lm_sensors-devel, systemd, git

Requires: findutils, xz

%{?systemd_requires}

%description
The sysstat package contains the sar, sadf, mpstat, iostat, tapestat,
pidstat, cifsiostat and sa tools for Linux.
The sar command collects and reports system activity information.
The information collected by sar can be saved in a file in a binary
format for future inspection. The statistics reported by sar concern
I/O transfer rates, paging activity, process-related activities,
interrupts, network activity, memory and swap space utilization, CPU
utilization, kernel activities and TTY statistics, among others. Both
UP and SMP machines are fully supported.
The sadf command may  be used to display data collected by sar in
various formats (CSV, PCP, XML, etc.).
The iostat command reports CPU utilization and I/O statistics for disks.
The tapestat command reports statistics for tapes connected to the system.
The mpstat command reports global and per-processor statistics.
The pidstat command reports statistics for Linux tasks (processes).
The cifsiostat command reports I/O statistics for CIFS file systems.

%package doc
Summary: Doc files for sysstat
Requires: %{name} = %{version}-%{release}
BuildArch: noarch

%description doc
Doc files for sysstat

%prep
%autosetup -S git_am

%build
%configure \
    --enable-install-cron \
    --enable-copy-only \
    --disable-file-attr \
    --disable-stripping \
    --docdir=%{_pkgdocdir} \
    sadc_options='-S DISK' \
    history=28 \
    compressafter=31
make %{?_smp_mflags}

%install
%make_install
%find_lang %{name}

# Colored sysstat output
mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -p -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/profile.d
install -p -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/profile.d

%generate_compatibility_deps

# for checkbuildroot
sed -e '/BUILDROOT/d' %{buildroot}/%{abidir}/sar-option.list > %{buildroot}/%{abidir}/sar-option.list.new
mv %{buildroot}/%{abidir}/sar-option.list.new %{buildroot}/%{abidir}/sar-option.list

rm -f %{buildroot}/usr/share/doc/sysstat/*

%post
%systemd_post sysstat.service sysstat-collect.timer sysstat-summary.timer

%preun
%systemd_preun sysstat.service sysstat-collect.timer sysstat-summary.timer
if [[ $1 -eq 0 ]]; then
    # Remove sa logs if removing sysstat completely
    rm -rf %{_localstatedir}/log/sa/*
fi

%postun
%systemd_postun sysstat.service sysstat-collect.timer sysstat-summary.timer

%files -f %{name}.lang
%license COPYING
%config(noreplace) %{_sysconfdir}/sysconfig/sysstat
%config(noreplace) %{_sysconfdir}/sysconfig/sysstat.ioconf
%config(noreplace) %{_sysconfdir}/profile.d/*
%{_bindir}/*
%{_libdir}/sa
%{_unitdir}/sysstat*
%{_systemd_util_dir}/system-sleep/sysstat*
%{_mandir}/man*/*
%{_localstatedir}/log/sa
%dir %{abidir}
%{abidir}/*

%files doc
%doc CHANGES FAQ.md README.md %{name}-%{version}.lsm CREDITS

%changelog
* Tue Jan 31 2023 Jing Zhang <renyu.zj@linux.alibaba.com> - 12.7.2-1
- update to 12.7.2

* Wed Oct 26 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 12.5.5-2
- remove pcp-libs-devel as BuildRequires
- add doc package and add abi files

* Tue Mar 08 2022 Yuanhong Peng <yummypeng@linux.alibaba.com> - 12.5.5-1
- Init from upstream v12.5.5
